# TimelineOMat

This project allows to streamline events in timelines. It is highly customizeable

## Installation
``` python
pip install timelineomat
```

## Usage

TODO:


TODO: add tests and documentation
